// Generated by CoffeeScript 1.12.7
(function() {
  var HttpError, humanname, mimeparse, selectMimeType, stripMetadata;

  humanname = require('humanname');

  mimeparse = require('mimeparse');

  HttpError = require('./http-error');

  stripMetadata = require('./strip-metadata');

  selectMimeType = function(contentType, supportedTypes) {
    if (contentType == null) {
      return;
    }
    return mimeparse.bestMatch(supportedTypes, contentType);
  };

  module.exports = {
    parseFullname: function(fullname) {
      var parsed;
      parsed = humanname.parse(fullname);
      return {
        salutation: parsed.salutation,
        first_name: parsed.firstName,
        middle_name: parsed.initials,
        last_name: parsed.lastName,
        suffix: parsed.suffix
      };
    },
    validateRequest: function(req, mimeTypes, methods) {
      var contentType, method, ref, supportedMethods;
      method = (ref = req.method) != null ? ref.toLowerCase() : void 0;
      supportedMethods = methods || ['POST'];
      supportedMethods = supportedMethods.map(function(val) {
        return val.toLowerCase();
      });
      if (!(supportedMethods.indexOf(method) > -1)) {
        throw new HttpError(415, {
          'Content-Type': 'text/plain',
          Allow: 'POST'
        }, "The " + (method.toUpperCase()) + " method is not allowed");
      }
      contentType = req.headers['Content-Type'];
      if (!contentType) {
        throw new HttpError(415, {
          'Content-Type': 'text/plain'
        }, 'Content-Type header is required');
      }
      if (!(mimeTypes.indexOf(selectMimeType(req.headers['Content-Type'], mimeTypes)) > -1)) {
        throw new HttpError(415, {
          'Content-Type': 'text/plain'
        }, "MIME type in Content-Type header is not supported. Use only " + (mimeTypes.join(', ')));
      }
    },
    calculateTimeout: function(startTimestamp, timeoutMs) {
      var elapsedMs, remaining;
      elapsedMs = new Date().getTime() - startTimestamp;
      remaining = timeoutMs - elapsedMs;
      if (remaining <= 0) {
        return 1;
      }
      return remaining;
    },
    stripMetadata: stripMetadata,
    getBaseUrl: function(env) {
      if (env == null) {
        env = process.env.NODE_ENV;
      }
      switch (env) {
        case 'staging':
          return 'https://next.staging.leadconduit.com';
        case 'development':
          return "http://leadconduit.localhost";
        default:
          return 'https://next.leadconduit.com';
      }
    }
  };

}).call(this);
